@@ -352,9 +352,8 @@ g_unix_error_string (int error_num)
 char *
 g_concat_dir_and_file (const char *dir, const char *file)
 {
-	/* If the directory name is NULL, return only the filename */
-	if (!dir)
-		return g_strdup(file);
+	g_return_val_if_fail (dir != NULL, NULL);
+	g_return_val_if_fail (file != NULL, NULL);
 
         /* If the directory name doesn't have a / on the end, we need
 	   to add one so we get a proper path to the file */
